Learn R Programming

istatR (version 0.1.0)

istat_get: Quick data retrieval

Description

A convenience function that combines creating a dataset, setting filters, and retrieving data in one call.

Usage

istat_get(
  dataflow_id,
  ...,
  start_period = NULL,
  end_period = NULL,
  last_n_observations = NULL
)

Value

A tibble containing the requested data

Arguments

dataflow_id

Dataflow ID (e.g., "139_176")

...

Named filter arguments (dimension_id = value)

start_period

Optional start date

end_period

Optional end date

last_n_observations

Optional integer to get only the last N observations

Examples

Run this code
if (FALSE) {
# Quick retrieval with filters
data <- istat_get(
  "139_176",
  FREQ = "M",
  TIPO_DATO = "ISAV",
  PAESE_PARTNER = "WORLD",
  start_period = "2020-01-01"
)
}

Run the code above in your browser using DataLab