Learn R Programming

istatR (version 0.1.0)

istat_timeout: Get or set the API timeout

Description

The ISTAT API can be slow to respond, especially for large queries. This function allows you to get or set the timeout value in seconds. The default timeout is 300 seconds (5 minutes).

Usage

istat_timeout(seconds = NULL)

Value

If seconds is NULL, returns the current timeout value. If seconds is provided, invisibly returns the previous timeout value.

Arguments

seconds

Optional. If provided, sets the timeout to this value in seconds. If NULL (default), returns the current timeout value.

Examples

Run this code
# Get current timeout
istat_timeout()

# Set timeout to 10 minutes
istat_timeout(600)

# Set timeout back to default
istat_timeout(300)

Run the code above in your browser using DataLab