Learn R Programming

istatR (version 0.1.0)

set_filters: Set filters for a dataset

Description

Sets dimension filters that will be used when retrieving data. Filter names should match dimension IDs (case-insensitive).

Usage

set_filters(dataset, ...)

Value

The modified istat_dataset object

Arguments

dataset

An istat_dataset object

...

Named arguments where names are dimension IDs and values are either single values or character vectors for multiple values. Use "." to select all values for a dimension.

Examples

Run this code
if (FALSE) {
ds <- istat_dataset("139_176")

# Set single values
ds <- set_filters(ds, FREQ = "M", PAESE_PARTNER = "WORLD")

# Set multiple values
ds <- set_filters(ds, TIPO_DATO = c("ISAV", "ESAV"))
}

Run the code above in your browser using DataLab