Provides an interface to the 'ISTAT' 'SDMX' RESTful API https://esploradati.istat.it/SDMXWS. Allows users to discover available datasets, explore their structure and dimensions, and retrieve statistical data from the Italian National Institute of Statistics. Based on the Python 'istatapi' package by Jacopo Attolini.
The istatR package provides an R interface to the ISTAT SDMX RESTful API, allowing users to discover available datasets, explore their structure and dimensions, and retrieve statistical data from the Italian National Institute of Statistics.
all_availableList all available ISTAT datasets
search_datasetSearch datasets by keyword
istat_datasetCreate a dataset object for exploration
get_dataRetrieve data from a dataset
library(istatR)# 1. Explore available datasets datasets <- all_available() import_ds <- search_dataset("import")
# 2. Create a dataset object ds <- istat_dataset("139_176")
# 3. Explore dimensions dimensions_info(ds) get_dimension_values(ds, "TIPO_DATO")
# 4. Set filters ds <- set_filters(ds, FREQ = "M", TIPO_DATO = c("ISAV", "ESAV"), PAESE_PARTNER = "WORLD" )
# 5. Retrieve data data <- get_data(ds)
Maintainer: Juan Ignacio Fulponi jfulponi@economicas.uba.ar
Useful links:
Useful links: